# botocore-stubs

[![PyPI - botocore-stubs](https://img.shields.io/pypi/v/botocore-stubs.svg?color=blue&label=botocore-stubs)](https://pypi.org/project/botocore-stubs)
[![PyPI - botocore](https://img.shields.io/pypi/v/botocore.svg?color=blue&label=botocore)](https://pypi.org/project/botocore)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/botocore-stubs.svg?color=blue)](https://pypi.org/project/botocore-stubs)
[![PyPI - Downloads](https://static.pepy.tech/badge/botocore-stubs)](https://pepy.tech/project/botocore-stubs)

![boto3.typed](https://github.com/youtype/mypy_boto3_builder/raw/main/logo.png)

Type annotations and code completion for [botocore](https://pypi.org/project/botocore/) package.
This package is a part of [mypy_boto3_builder](https://github.com/youtype/mypy_boto3_builder) project.

[![Publish botocore-stubs](https://github.com/youtype/botocore-stubs/actions/workflows/publish_on_update.yml/badge.svg)](https://github.com/youtype/botocore-stubs/actions/workflows/publish_on_update.yml)
[![Publish types-awscrt](https://github.com/youtype/types-awscrt/actions/workflows/publish_on_update.yml/badge.svg)](https://github.com/youtype/types-awscrt/actions/workflows/publish_on_update.yml)
[![Publish types-s3transfer](https://github.com/youtype/types-s3transfer/actions/workflows/publish_on_update.yml/badge.svg)](https://github.com/youtype/types-s3transfer/actions/workflows/publish_on_update.yml)

- [botocore-stubs](#botocore-stubs)
  - [Installation](#installation)
  - [Usage](#usage)
  - [Versioning](#versioning)
  - [Support and contributing](#support-and-contributing)

## Installation

```bash
python -m pip install botocore-stubs
```

## Usage

Use [mypy](https://github.com/python/mypy) or [pyright](https://github.com/microsoft/pyright) for type checking.

## Versioning

`botocore-stubs` version is the same as related `botocore` version and follows
[PEP 440](https://www.python.org/dev/peps/pep-0440/) format.

## Support and contributing

Please reports any bugs or request new features in
[botocore-stubs](https://github.com/youtype/botocore-stubs/issues/) repository.
